@@ -154,8 +154,8 @@ class Type(ModelSQL, ModelView):
     name = fields.Char('Name', size=None, required=True, translate=True)
     parent = fields.Many2One('account.account.type', 'Parent',
         ondelete="RESTRICT", domain=[
-            ('company', '=', Eval('context', {}).get('company')),
-            ])
+            ('company', '=', Eval('company')),
+            ], depends=['company'])
     childs = fields.One2Many('account.account.type', 'parent', 'Children',
         domain=[
             ('company', '=', Eval('company')),
@@ -854,6 +854,7 @@ class Account(ModelSQL, ModelView):
             default = {}
         default['left'] = 0
         default['right'] = 0
+        default.setdefault('deferrals', [])
         res = super(Account, self).copy(ids, default=default)
         self._rebuild_tree('parent', False, 0)
         return res
@@ -1824,13 +1825,14 @@ class CreateChartAccount(Wizard):
             ])
         with Transaction().set_user(0):
             property_obj.delete(property_ids)
-            property_obj.create({
-                'name': 'account_receivable',
-                'field': account_receivable_field_id,
-                'value': 'account.account,' + \
-                        str(datas['form']['account_receivable']),
-                'company': datas['form']['company'],
-                })
+            if datas['form']['account_receivable']:
+                property_obj.create({
+                    'name': 'account_receivable',
+                    'field': account_receivable_field_id,
+                    'value': 'account.account,' + \
+                            str(datas['form']['account_receivable']),
+                    'company': datas['form']['company'],
+                    })
 
         account_payable_field_id = model_field_obj.search([
             ('model.model', '=', 'party.party'),
@@ -1843,13 +1845,14 @@ class CreateChartAccount(Wizard):
             ])
         with Transaction().set_user(0):
             property_obj.delete(property_ids)
-            property_obj.create({
-                'name': 'account_payable',
-                'field': account_payable_field_id,
-                'value': 'account.account,' + \
-                        str(datas['form']['account_payable']),
-                'company': datas['form']['company'],
-                })
+            if datas['form']['account_payable']:
+                property_obj.create({
+                    'name': 'account_payable',
+                    'field': account_payable_field_id,
+                    'value': 'account.account,' + \
+                            str(datas['form']['account_payable']),
+                    'company': datas['form']['company'],
+                    })
         return {}
 
 CreateChartAccount()
